<?php
/**
 * WooCommerce Jilt
 *
 * This source file is subject to the GNU General Public License v3.0
 * that is bundled with this package in the file license.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@jilt.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade WooCommerce Jilt to newer
 * versions in the future. If you wish to customize WooCommerce Jilt for your
 * needs please refer to http://help.jilt.com/jilt-for-woocommerce
 *
 * @package   WC-Jilt/Integrations
 * @author    Jilt
 * @category  Frontend
 * @copyright Copyright (c) 2015-2019, SkyVerge, Inc.
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License v3.0
 */

defined( 'ABSPATH' ) or exit;

use SkyVerge\WooCommerce\PluginFramework\v5_2_1 as Framework;

/**
 * Integration with WooCommerce Subscriptions.
 *
 * @since 1.5.5
 */
class WC_Jilt_Subscriptions_Integration extends WC_Jilt_Integration_Base {


	/**
	 * Adds hooks for WooCommerce Subscriptions.
	 *
	 * @since 1.5.5
	 */
	public function __construct() {

		// add data to the subscriptions REST API response output
		add_filter( 'woocommerce_rest_prepare_shop_subscription', array( $this, 'add_subscription_rest_api_response_data' ), 20, 2 );
	}


	/**
	 * Returns the integration title.
	 *
	 * @since 1.5.5
	 *
	 * @return string
	 */
	public function get_title() {

		return __( 'Subscriptions', 'jilt-for-woocommerce' );
	}


	/**
	 * Determines whether Subscriptions is installed and active.
	 *
	 * @since 1.5.5
	 *
	 * @return bool
	 */
	public function is_active() {

		return wc_jilt()->is_plugin_active( 'woocommerce-subscriptions.php' );
	}


	/**
	 * Adds additional data to a Subscription's REST API response.
	 *
	 * @internal
	 *
	 * @since 1.5.5
	 *
	 * @param \WP_REST_Response $response response object
	 * @param \WP_Post $post the subscription post object
	 * @return \WP_REST_Response
	 */
	public function add_subscription_rest_api_response_data( $response, $post ) {

		if ( 'shop_subscription' === get_post_type( $post ) && ( $subscription = wcs_get_subscription( $post->ID ) ) ) {

			$data = (array) $response->get_data();

			$data['jilt'] = array(
				// adds a "View URL" front end link similar to that provided by Memberships in the user memberships REST API responses
				'view_url' => $subscription->get_view_order_url(),
			);

			$response->set_data( $data );
		}

		return $response;
	}


}
